@@ -7,7 +7,7 @@ use warnings;
 use Exporter 'import';
 
 our @EXPORT_OK = qw(read_sxc read_sxc_fh read_xml_file read_xml_string);
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Archive::Zip ':ERROR_CODES';
 use XML::Parser;
@@ -145,7 +145,9 @@ sub handle_start {
 sub handle_end {
     my ($expat, $element) = @_;
     if ( $element eq "text:p" ) {
-        $cell[ $text_p ] ||= undef;
+        if( ! $expat->within_element('office:annotation') ) {
+            $cell[ $text_p ] ||= undef;
+        };
     }
     elsif ( $element eq "table:table") {
 # decrease $max_datacol if hidden columns within range
